@@ -7,7 +7,18 @@ class usbconfig:
 	DEF_PAD = 5
 	FUNCTION_TYPE="net"
 	STORAGE_DEVICE = "/dev/hda1"
-	STORAGE_OPTS = ["/dev/hda1","/dev/mmcda1"]	
+
+	f = open("/proc/deviceinfo/product","r")
+	MODEL = f.read()
+	f.close()
+	print MODEL
+
+	if (MODEL.find("SL-C3100") != -1):
+	    STORAGE_OPTS = ["/dev/mmcda1","/dev/hda1","/dev/hda2","/dev/hda3","/dev/hdc1","/dev/hdc2","/dev/hdc3"]
+	elif os.path.exists("/dev/.devfsd"):
+	    STORAGE_OPTS = ["/dev/mmcd/disc0/part1","/dev/hda1"]
+	else:
+	    STORAGE_OPTS = ["/dev/mmcda1","/dev/hda1"]
 
 	if os.name == "nt":
 		USB_TYPE_FILE = "C:\\python24\\pdaxrom\\misc\\usbd.ftype"
@@ -110,8 +121,16 @@ class usbconfig:
 		hbox.pack_start(self.storage_button, gtk.FALSE, gtk.TRUE, 0)
 		
 		self.storage_type_menu = gtk.combo_box_new_text()
-        	self.storage_type_menu.append_text("Compact Flash (CF)")
         	self.storage_type_menu.append_text("Secure Digital (SD)")
+		if (self.MODEL.find("SL-C3100") != -1):
+		    self.storage_type_menu.append_text("Compact Flash (CF 0,1)")
+		    self.storage_type_menu.append_text("Compact Flash (CF 0,2)")
+		    self.storage_type_menu.append_text("Compact Flash (CF)0,3")
+		    self.storage_type_menu.append_text("Compact Flash (CF)1,1")
+		    self.storage_type_menu.append_text("Compact Flash (CF)1,2")
+		    self.storage_type_menu.append_text("Compact Flash (CF)1,3")
+		else:
+        	    self.storage_type_menu.append_text("Compact Flash (CF)")
 	        self.storage_type_menu.connect('changed', self.change_storage_type)
 		self.storage_type_menu.set_size_request(180,30)
 
@@ -141,12 +160,26 @@ class usbconfig:
 			self.change_usbtype(None,"serial")
 			self.serial_button.set_active(gtk.TRUE)
 		
-		if (self.STORAGE_DEVICE == "/dev/mmcda1"):
-			self.storage_type_menu.set_active(1)
-		else:
-			self.storage_type_menu.set_active(0)
+		self.find_storage(self.STORAGE_DEVICE)
+		
+		#if (self.STORAGE_DEVICE == "/dev/mmcda1"):
+		#	self.storage_type_menu.set_active(0)
+		#else:
+		#	self.storage_type_menu.set_active(1)
+		
 		self.window.show_all()
 
+	def find_storage(self, data=None):
+		n = 0
+		for dev in self.STORAGE_OPTS:
+		    if (dev == data):
+			self.storage_type_menu.set_active(n)
+			return True
+		    else:
+			n = n + 1
+		self.storage_type_menu.set_active(0)
+		return False
+
 	def change_usbtype(self, widget, data=None):
 		if (data == "net"):
 			self.storage_type_menu.set_sensitive(gtk.FALSE)
@@ -187,6 +220,7 @@ class usbconfig:
 			writestr = writestr + "DHCPC=no\n";
 			f.write(writestr)
 			f.close()
+			os.system("rm -f /etc/hotplug/usbdstorage.conf");
 		elif (self.FUNCTION_TYPE == "storage"):
 			f=open(self.USB_STORAGE_TYPE_FILE, "w")
 			f.write(self.STORAGE_DEVICE+ "\n")
